#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 http3
version:              0.0.9
visibility:           public
id:                   http3-0.0.9-4mZyQOzzwpTB3c3q8JSZIz
key:                  http3-0.0.9-4mZyQOzzwpTB3c3q8JSZIz
license:              BSD-3-Clause
maintainer:           Kazu Yamamoto <kazu@iij.ad.jp>
author:               Kazu Yamamoto <kazu@iij.ad.jp>
homepage:             https://github.com/kazu-yamamoto/http3
synopsis:             HTTP/3 library
description:          HTTP/3 library including frames, QPACK, client and server.
category:             Network
abi:                  9e9489ed965b6237285f005c96ecb8b2
exposed:              True
exposed-modules:
    Network.HQ.Client Network.HQ.Server Network.HTTP3.Client
    Network.HTTP3.Internal Network.HTTP3.Server Network.QPACK
    Network.QPACK.Internal

hidden-modules:
    Imports Network.HTTP3.Config Network.HTTP3.Context
    Network.HTTP3.Control Network.HTTP3.Error Network.HTTP3.Frame
    Network.HTTP3.Recv Network.HTTP3.Send Network.HTTP3.Settings
    Network.HTTP3.Stream Network.QPACK.Error Network.QPACK.HeaderBlock
    Network.QPACK.HeaderBlock.Decode Network.QPACK.HeaderBlock.Encode
    Network.QPACK.HeaderBlock.Prefix Network.QPACK.Instruction
    Network.QPACK.Table Network.QPACK.Table.Dynamic
    Network.QPACK.Table.RevIndex Network.QPACK.Table.Static
    Network.QPACK.Token Network.QPACK.Types

import-dirs:          /usr/lib/ghc-9.6.6/site-local/http3-0.0.9
library-dirs:         /usr/lib/ghc-9.6.6/site-local/http3-0.0.9
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/http3-0.0.9
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-http3
hs-libraries:         HShttp3-0.0.9-4mZyQOzzwpTB3c3q8JSZIz
depends:
    array-0.5.6.0 base-4.18.2.1 bytestring-0.11.5.3
    case-insensitive-1.2.1.0-KRBUDrDZZz8K0kWnqUEh6i containers-0.6.7
    http-types-0.12.4-DIRo50xDRxbE4a3m2IKFXS
    http2-5.1.2-BXYOVkAionvH53EPrLbaTf
    network-3.1.4.0-5CNSYfJ9OXEKTDv1UbcApF
    network-byte-order-0.1.7-KOrHLkTNWo52qSQao8kAgk
    quic-0.1.28-I1cEX3gUWAhG9i609M46Wi
    sockaddr-0.0.1-H55KnwNUtGbCztHpQufkwC stm-2.5.1.0
    time-manager-0.0.1-6RsAUM7t8NPDFTj3IDNz6N
    unliftio-0.2.25.1-4sSt3OjSW4r1pFFb98bYkM

haddock-interfaces:   /usr/share/doc/haskell-http3/html/http3.haddock
haddock-html:         /usr/share/doc/haskell-http3/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

